CookieUtils
=========================
A modual for usfull utilitys i always needed

Install
--------
To install the modual run
```console
pip install cookieutils
```
for more info visit [https://epic-oreo.gitbook.io/cookie-utils/](https://epic-oreo.gitbook.io/cookie-utils/)